GestureConfig

Struct GestureConfig 

pub struct GestureConfig {
    pub tap_max_distance: f32,
    pub tap_max_duration: f32,
    pub swipe_min_distance: f32,
    pub long_press_duration: f32,
    pub double_tap_max_interval: f32,
}
Gesture recognition thresholds.

Fields

tap_max_distance: f32

Maximum pointer travel for a tap or long press.

tap_max_duration: f32

Maximum duration, in seconds, for a tap.

swipe_min_distance: f32

Minimum pointer travel for a swipe.

long_press_duration: f32

Minimum duration, in seconds, for a long press.

double_tap_max_interval: f32

Maximum interval, in seconds, between taps for a double tap.