pub struct GestureConfig {
pub tap_max_distance: f32,
pub tap_max_duration: f32,
pub swipe_min_distance: f32,
pub long_press_duration: f32,
pub double_tap_max_interval: f32,
}Expand description
Gesture recognition thresholds.
Fields
tap_max_distance: f32Maximum pointer travel for a tap or long press.
tap_max_duration: f32Maximum duration, in seconds, for a tap.
swipe_min_distance: f32Minimum pointer travel for a swipe.
long_press_duration: f32Minimum duration, in seconds, for a long press.
double_tap_max_interval: f32Maximum interval, in seconds, between taps for a double tap.