pub struct InertiaConfig<T = f32> {
pub friction: f32,
pub min_velocity: f32,
pub bounds: Option<InertiaBounds<T>>,
}Expand description
Configuration for friction inertia.
friction is a constant deceleration in units per second squared.
min_velocity is the absolute velocity threshold below which inertia is
considered settled.
Fields
friction: f32Constant deceleration in units per second squared.
min_velocity: f32Velocity threshold below which the inertia settles.
bounds: Option<InertiaBounds<T>>Optional inclusive bounds for the position.
Implementations
Sourceimpl<T> InertiaConfig<T>
impl<T> InertiaConfig<T>
Sourcepub fn with_bounds(self, bounds: InertiaBounds<T>) -> Self
pub fn with_bounds(self, bounds: InertiaBounds<T>) -> Self
Attach inclusive position bounds.
Sourceimpl InertiaConfig<f32>
impl InertiaConfig<f32>